typedef struct descr_t {
	const char *name;
	const char *set;
	const char *descr;
} descr_t;

static descr_t	descrs[] = {
	{ "asa", "[format]", "perform Fortran control character transformations in the form of the POSIX asa(1) command." },
	{ "ascii2ebcdic", "[charset]", "convert the input from ASCII character encodings to EBCDIC character encodings." },
	{ "base64decode", "[charset]", "perform atob, or base64, decoding. Each sequence of 4 bytes is transformed back into a 3 byte sequence." },
	{ "base64encode", "[charset]", "perform atob, or base64, encoding. Each sequence of 3 bytes is transformed into a 4 byte sequence from the pre-defined 64-byte set." },
	{ "base85decode", "[charset]", "perform base85 decoding. Each sequence of 5 bytes is transformed back into a 4 byte sequence." },
	{ "base85encode", "[charset]", "perform base85 encoding. Each sequence of 4 bytes is transformed into a 5 byte sequence from the pre-defined 85-byte set." },
	{ "bin2hex", "[charset]", "encodes the input string as 4-character C-string style hexadecimal constants." },
	{ "bswap16", "[format]", "perform a bytewise swap of the 16-bit entity" },
	{ "bswap32", "[format]", "perform a bytewise swap of the 32-bit entity" },
	{ "bswap64", "[format]", "perform a bytewise swap of the 64-bit entity" },
	{ "dos2unix", "[format]", "DOS style line-endings are transformed into Unix style line-endings." },
	{ "ebcdic2ascii", "[charset]", "convert the input from EBCDIC character encodings to ASCII character encodings." },
	{ "edit", "[edit]", "edit the input text with the ``EDITOR'' or ``VISUAL'' editor, as defined in the environment." },
	{ "from-uri", "[charset]", "convert from a percent-encoded URI to ASCII text." },
	{ "full-uuencode", "[charset]", "convert the given text into uuencoded text (see also the uuencode and uudecode transforms), adding a file header and trailer." },
	{ "gethostinfo", "[network]", "attempt to resolve the hostname, given the IP address (either IPv4 or IPv6) as input." },
	{ "getipaddress", "[network]", "attempt to reverse resolve the IP address (both IPv4 and IPv6) given the hostname as input." },
	{ "gunzip", "[compress]", "decompress the input buffer using zlib(3)" },
	{ "gzip", "[compress]", "compress the input buffer using zlib(3)" },
	{ "hex2bin", "[charset]", "decodes the input string from 4-character C-string style hexadecimal constants to binary output." },
	{ "hexdump", "[format]", "converts the input text to an ASCII-clean hexadecimal dump format, including a printable representation of the input text." },
	{ "md5", "[digest]", "calculate the MD5 digest using MD5_Data(3)" },
	{ "metaphone", "[charset]", "calculate the metaphone phonetic value for the input." },
	{ "rad50decode", "[charset]", "converts the input text from DEC RADIX-50 format to the original text. Due to the limited range of the RADIX-50 character set, some of the original text may have been lost." },
	{ "rad50encode", "[charset]", "converts the input text to DEC RADIX-50 format from the original text. Due to the limited range of the RADIX-50 character set, some of the original text may have been lost." },
	{ "randomise", "[fill]", "fill the output with random values." },
	{ "rmd160", "[digest]", "calculate the RMD160 digest using RMD160_Data(3)" },
	{ "rot", "[format]", "transform the input text with a circular rotation. The most famous of these is the Caesar rot13(6) transformation, but this transformation allows any length of rotation to be used." },
	{ "secs2str", "[format]", "transforms the input value (as the ASCII-encoded decimal value of seconds since the start of the epoch) to a colon-separated value representing the date." },
	{ "sed", "[edit]", "performs a sed(1) transformation on a regular expression. Please note that full, extended regular expressions, as defined in re_format(7) are used to match." },
	{ "size", "[digest]", "returns the size of the input as a decimal string" },
	{ "sha1", "[digest]", "calculate the SHA1 digest using SHA1Data(3)" },
	{ "sha256", "[digest]", "calculate the SHA256 digest using SHA256_Data(3)" },
	{ "sha512", "[digest]", "calculate the SHA512 digest using SHA512_Data(3)" },
	{ "soundex", "[charset]", "calculate the soundex phonetic value for the input." },
	{ "str2secs", "[format]", "transforms the input value (as the colon-separated value representing the date) to an ASCII-encoded decimal value representing seconds since the start of the epoch." },
	{ "strunvis", "[charset]", "uses the unstrvis(3) transformation on the input data." },
	{ "strvis", "[charset]", "uses the strvis(3) transformation on the input data." },
	{ "strvisc", "[charset]", "uses the strvisc(3) transformation on the input data." },
	{ "substring", "[edit]", "extract a substring of the input string, and place it in the output string." },
	{ "to-uri", "[charset]", "convert from a percent-encoded URI to ASCII text." },
	{ "to-lower", "[charset]", "change any uppercase letters in the input string to lowercase." },
	{ "to-unicode", "[charset]", "translate to unicode-16 from UTF-8" },
	{ "to-upper", "[charset]", "change any lowercase letters in the input string to uppercase." },
	{ "to-utf8", "[charset]", "translate from unicode-16 to UTF-8" },
	{ "unix2dos", "[charset]", "the Unix-style line-endings are converted to DOS style line-endings." },
	{ "uudecode", "[charset]", "transform the input text from uudecode(1) text to the original text." },
	{ "uuencode", "[charset]", "encode the input text as uuencode(1) text." },
	{ "zero", "[fill]", "produce an area containing NUL bytes in the output." },
	{ "dumbhash", "[hash]", "implements a simple hashing scheme based on the addition of the value of each character in the string." },
	{ "dumbmulhash", "[hash]", "implements a simple hashing scheme based on the addition of the value of each character in the string multiplied by its position in the string." },
	{ "lennart", "[hash]", "implements a simple and fast generic string hasher based on Peter K. Pearson's article in CACM 33-6, pp. 677." },
	{ "crchash", "[hash]", "implements a hash used in CRC calculations" },
	{ "perlhash", "[hash]", "implements the addition-based hash algorithm used internally in the perl interpreter." },
	{ "perlxorhash", "[hash]", "implements the XOR-based hash algorithm used internally in the perl interpreter." },
	{ "pythonhash", "[hash]", "implements the hash algorithm used internally in the python interpreter." },
	{ "mousehash", "[hash]", "implements an XOR-based hash algorithm from der Mouse." },
	{ "bernstein", "[hash]", "implements a multiplicative-based hash algorithm from Daniel Bernstein." },
	{ "honeyman", "[hash]", "implements an XOR-based hash algorithm from Peter Honeyman." },
	{ "pjwhash", "[hash]", "implements the so called `hashpjw' function by P.J. Weinberger from Aho/Sethi/Ullman, COMPILERS: Principles, Techniques and Tools, 1986, 1987 Bell Telephone Laboratories, Inc." },
	{ "bobhash", "[hash]", "implements another, more complex hash algorithm." },
	{ "torekhash", "[hash]", "implements a hash algorithm due to Chris Torek, and using Duff's device." },
	{ "byacchash", "[hash]", "implements the hash function found in Berkeley byacc(1) program" },
	{ "tclhash", "[hash]", "implements the hash algorithm used internally in the tcl interpreter." },
	{ "gawkhash", "[hash]", "implements the hash algorithm used internally in the gawk interpreter, also using Duff's device." },
	{ "gcc3_hash", "[hash]", "implements one of the hash algorithms found in gcc3" },
	{ "gcc3_hash2", "[hash]", "implements another of the hash algorithms found in gcc3" },
	{ "nemhash", "[hash]", "implements another hash function" },
	{ NULL, NULL, NULL }
};

